@@ -1,8 +1,19 @@
-from typing import TYPE_CHECKING, Any, Dict, Generic, Optional, Type, TypeVar
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Generic,
+    Optional,
+    Type,
+    TypeVar,
+)
 
+from pydantic import BaseModel
 from pydantic_core import core_schema
 
 from ninja import Body
+from ninja.orm import ModelSchema
+from ninja.schema import Schema
 from ninja.utils import is_optional_type
 
 
@@ -22,10 +33,24 @@ class ModelToDict(dict):
         return input_value.model_dump(**cls._wrapped_model_dump_params)
 
 
+def get_schema_annotations(schema_cls: Type[Any]) -> Dict[str, Any]:
+    annotations: Dict[str, Any] = {}
+    excluded_bases = {Schema, ModelSchema, BaseModel}
+    bases = schema_cls.mro()[:-1]
+    final_bases = reversed([b for b in bases if b not in excluded_bases])
+
+    for base in final_bases:
+        annotations.update(getattr(base, "__annotations__", {}))
+
+    return annotations
+
+
 def create_patch_schema(schema_cls: Type[Any]) -> Type[ModelToDict]:
+    schema_annotations = get_schema_annotations(schema_cls)
     values, annotations = {}, {}
-    for f in schema_cls.__fields__.keys():
-        t = schema_cls.__annotations__[f]
+    # assert False, f"{schema_cls} - {schema_cls.model_fields}"
+    for f in schema_cls.model_fields.keys():
+        t = schema_annotations[f]
         if not is_optional_type(t):
             values[f] = getattr(schema_cls, f, None)
             annotations[f] = Optional[t]
